==> zhiyuan-openapi-sdk-0.0.27-20251104.013335-1-sources.jar: com/elitesland/zhiyuan/openapi/outer/jackyun/data/bizdata/erp/erpstoragegoodsdocoutv2/ErpStorageGoodsDocOutV2ResponseBizData.java <==
package com.elitesland.zhiyuan.openapi.outer.jackyun.data.bizdata.erp.erpstoragegoodsdocoutv2;



import com.elitesland.zhiyuan.openapi.outer.jackyun.data.bizdata.core.BaseResponseBizData;

import java.math.BigDecimal;
import java.util.List;
/**
 * @description: 分页查询出库单返回参数
 * @author: luoxin
 */ 
public class ErpStorageGoodsDocOutV2ResponseBizData extends BaseResponseBizData {
	/**
	 * 出库单ID 
	 */ 
	private Long recId;
	/**
	 * 出库单号 
	 */ 
	private String goodsdocNo;
	/**
	 * 上游单据号(关联单号) 
	 */ 
	private String billNo;
	/**
	 * 出库时间 
	 */ 
	private String inOutDate;
	/**
	 * 创建时间 
	 */ 
	private String gmtCreate;
	/**
	 * 出入库类型(201-销售出库 202调拨出库 204-其他出库 205采购退货 206生产领料 207组装拆卸出库 208翻新出库 209报废出库 210残次品出库 211倒冲领料 212 包材出库 215维修还厂 299可用库存修正 231成本调整出库) 
	 */ 
	private Integer inouttype;
	/**
	 * 出入库类型(201-销售出库 202调拨出库 204-其他出库 205采购退货 206生产领料 207组装拆卸出库 208翻新出库 209报废出库 210残次品出库 211倒冲领料 212 包材出库 215维修还厂 299可用库存修正 231成本调整出库) 
	 */ 
	private String inouttypeName;
	/**
	 * 往来单位名称 
	 */ 
	private String vendCustomerName;
	/**
	 * 币种编号 
	 */ 
	private String currencyCode;
	/**
	 * 币种汇率 
	 */ 
	private BigDecimal currencyRate;
	/**
	 * 业务员名字 
	 */ 
	private String userName;
	/**
	 * 仓库编号 
	 */ 
	private String warehouseCode;
	/**
	 * 仓库名字 
	 */ 
	private String warehouseName;
	/**
	 * 备注 
	 */ 
	private String comment;
	/**
	 * 收货备注 
	 */ 
	private String memo;
	/**
	 * 物流公司 
	 */ 
	private String logisticName;
	/**
	 * 物流单号 
	 */ 
	private String logisticNo;
	/**
	 * 公司id 
	 */ 
	private Long companyId;
	/**
	 * 公司名称 
	 */ 
	private String companyName;
	/**
	 * 物流类型1-普通快递 2-上门自提 3-门店配送5-无需配送 6-线下配送 
	 */ 
	private String logisticType;
	/**
	 * 物流公司编码 
	 */ 
	private String logisticCode;
	/**
	 * 出库原因 
	 */ 
	private String inOutReason;
	/**
	 * 来源单号 
	 */ 
	private String sourceBillNo;
	/**
	 * 渠道ID 
	 */ 
	private Long channelId;
	/**
	 * 渠道编号 
	 */ 
	private String channelCode;
	/**
	 * 渠道名称 
	 */ 
	private String channelName;
	/**
	 * 红冲状态：1蓝单（未红冲）；2被冲蓝单；9红冲单 
	 */ 
	private Byte redStatus;
	/**
	 * 自定义字段1 
	 */ 
	private String field1;
	/**
	 * 自定义字段2 
	 */ 
	private String field2;
	/**
	 * 自定义字段3 
	 */ 
	private String field3;
	/**
	 * 自定义字段4 
	 */ 
	private String field4;
	/**
	 * 自定义字段5 
	 */ 
	private String field5;
	/**
	 * 财务状态：1：未成本计算；11部分成本计算；21：已成本计算；25已财务记账；31不成本计算 
	 */ 
	private Byte financeBillStatus;
	/**
	 * 往来单位的id 
	 */ 
	private String vendCustomerId;
	/**
	 * 申请人部门id 
	 */ 
	private Long applyDepartId;
	/**
	 * 申请人部门名称 
	 */ 
	private String applyDepartName;
	/**
	 * 外部单号 
	 */ 
	private String outBillNo;
	/**
	 * 物流信息 
	 */ 
	private List<LogisticList> logisticList;
	/**
	 * 最近修改时间 
	 */ 
	private String gmtModified;
	/**
	 * 申请人部门编号 
	 */ 
	private String departCode;
	/**
	 * 申请人公司名称 
	 */ 
	private String applyCompanyName;
	/**
	 * 申请人公司编号 
	 */ 
	private String applyCompanyCode;
	/**
	 * 申请人公司id 
	 */ 
	private Long applyCompanyId;
	/**
	 * 申请人id 
	 */ 
	private Long applyUserId;
	/**
	 * 申请人名称 
	 */ 
	private String applyUserName;
	/**
	 * 公司编号 
	 */ 
	private String companyCode;
	/**
	 * 出库单详情 
	 */ 
	private List<GoodsDocDetailList> goodsDocDetailList;
	/**
	 * 发件公司名称 
	 */ 
	private String sendCompanyName;
	/**
	 * 发件人 
	 */ 
	private String send;
	/**
	 * 发件人电话 
	 */ 
	private String sendTel;
	/**
	 * 发件人手机号 
	 */ 
	private String sendPhone;
	/**
	 * 发件人邮箱 
	 */ 
	private String sendEmail;
	/**
	 * 发件人国家 
	 */ 
	private String sendCountryName;
	/**
	 * 发件人省 
	 */ 
	private String sendProvinceName;
	/**
	 * 发件人市 
	 */ 
	private String sendCityName;
	/**
	 * 发件人镇，区 
	 */ 
	private String sendTownName;
	/**
	 * 发件人街道 
	 */ 
	private String sendStreetName;
	/**
	 * 发件人详细地址 
	 */ 
	private String sendAddress;
	/**
	 * 收件公司名称 
	 */ 
	private String receiveCompanyName;
	/**
	 * 收件人 
	 */ 
	private String receive;
	/**
	 * 收件人电话 
	 */ 
	private String receiveTel;
	/**
	 * 收件人手机号 
	 */ 
	private String receivePhone;
	/**
	 * 收件人邮箱 
	 */ 
	private String receiveEmail;
	/**
	 * 收件人国家 
	 */ 
	private String receiveCountryName;
	/**
	 * 收件人省 
	 */ 
	private String receiveProvinceName;
	/**
	 * 收件人市 
	 */ 
	private String receiveCityName;
	/**
	 * 收件人镇，区 
	 */ 
	private String receiveTownName;
	/**
	 * 收件人街道 
	 */ 
	private String receiveStreetName;
	/**
	 * 收件人详细地址 
	 */ 
	private String receiveAddress;
	/**
	 * 自定义字段6 
	 */ 
	private String field6;
	/**
	 * 自定义字段7 
	 */ 
	private String field7;
	/**
	 * 自定义字段8 
	 */ 
	private String field8;
	/**
	 * 自定义字段9 
	 */ 
	private String field9;
	/**
	 * 自定义字段10 
	 */ 
	private String field10;

	public Long getRecId() {
		return recId;
	}

	public void setRecId(Long recId) {
		this.recId = recId;
	}

	public String getGoodsdocNo() {
		return goodsdocNo;
	}

	public void setGoodsdocNo(String goodsdocNo) {
		this.goodsdocNo = goodsdocNo;
	}

	public String getBillNo() {
		return billNo;
	}

	public void setBillNo(String billNo) {
		this.billNo = billNo;
	}

	public String getInOutDate() {
		return inOutDate;
	}

	public void setInOutDate(String inOutDate) {
		this.inOutDate = inOutDate;
	}

	public String getGmtCreate() {
		return gmtCreate;
	}

	public void setGmtCreate(String gmtCreate) {
		this.gmtCreate = gmtCreate;
	}

	public Integer getInouttype() {
		return inouttype;
	}

	public void setInouttype(Integer inouttype) {
		this.inouttype = inouttype;
	}

	public String getInouttypeName() {
		return inouttypeName;
	}

	public void setInouttypeName(String inouttypeName) {
		this.inouttypeName = inouttypeName;
	}

	public String getVendCustomerName() {
		return vendCustomerName;
	}

	public void setVendCustomerName(String vendCustomerName) {
		this.vendCustomerName = vendCustomerName;
	}

	public String getCurrencyCode() {
		return currencyCode;
	}

	public void setCurrencyCode(String currencyCode) {
		this.currencyCode = currencyCode;
	}

	public BigDecimal getCurrencyRate() {
		return currencyRate;
	}

	public void setCurrencyRate(BigDecimal currencyRate) {
		this.currencyRate = currencyRate;
	}

	public String getUserName() {
		return userName;
	}

	public void setUserName(String userName) {
		this.userName = userName;
	}

	public String getWarehouseCode() {
		return warehouseCode;
	}

	public void setWarehouseCode(String warehouseCode) {
		this.warehouseCode = warehouseCode;
	}

	public String getWarehouseName() {
		return warehouseName;
	}

	public void setWarehouseName(String warehouseName) {
		this.warehouseName = warehouseName;
	}

	public String getComment() {
		return comment;
	}

	public void setComment(String comment) {
		this.comment = comment;
	}

	public String getMemo() {
		return memo;
	}

	public void setMemo(String memo) {
		this.memo = memo;
	}

	public String getLogisticName() {
		return logisticName;
	}

	public void setLogisticName(String logisticName) {
		this.logisticName = logisticName;
	}

	public String getLogisticNo() {
		return logisticNo;
	}

	public void setLogisticNo(String logisticNo) {
		this.logisticNo = logisticNo;
	}

	public Long getCompanyId() {
		return companyId;
	}

	public void setCompanyId(Long companyId) {
		this.companyId = companyId;
	}

	public String getCompanyName() {
		return companyName;
	}

	public void setCompanyName(String companyName) {
		this.companyName = companyName;
	}

	public String getLogisticType() {
		return logisticType;
	}

	public void setLogisticType(String logisticType) {
		this.logisticType = logisticType;
	}

	public String getLogisticCode() {
		return logisticCode;
	}

	public void setLogisticCode(String logisticCode) {
		this.logisticCode = logisticCode;
	}

	public String getInOutReason() {
		return inOutReason;
	}

	public void setInOutReason(String inOutReason) {
		this.inOutReason = inOutReason;
	}

	public String getSourceBillNo() {
		return sourceBillNo;
	}

	public void setSourceBillNo(String sourceBillNo) {
		this.sourceBillNo = sourceBillNo;
	}

	public Long getChannelId() {
		return channelId;
	}

	public void setChannelId(Long channelId) {
		this.channelId = channelId;
	}

	public String getChannelCode() {
		return channelCode;
	}

	public void setChannelCode(String channelCode) {
		this.channelCode = channelCode;
	}

	public String getChannelName() {
		return channelName;
	}

	public void setChannelName(String channelName) {
		this.channelName = channelName;
	}

	public Byte getRedStatus() {
		return redStatus;
	}

	public void setRedStatus(Byte redStatus) {
		this.redStatus = redStatus;
	}

	public String getField1() {
		return field1;
	}

	public void setField1(String field1) {
		this.field1 = field1;
	}

	public String getField2() {
		return field2;
	}

	public void setField2(String field2) {
		this.field2 = field2;
	}

	public String getField3() {
		return field3;
	}

	public void setField3(String field3) {
		this.field3 = field3;
	}

	public String getField4() {
		return field4;
	}

	public void setField4(String field4) {
		this.field4 = field4;
	}

	public String getField5() {
		return field5;
	}

	public void setField5(String field5) {
		this.field5 = field5;
	}

	public Byte getFinanceBillStatus() {
		return financeBillStatus;
	}

	public void setFinanceBillStatus(Byte financeBillStatus) {
		this.financeBillStatus = financeBillStatus;
	}

	public String getVendCustomerId() {
		return vendCustomerId;
	}

	public void setVendCustomerId(String vendCustomerId) {
		this.vendCustomerId = vendCustomerId;
	}

	public Long getApplyDepartId() {
		return applyDepartId;
	}

	public void setApplyDepartId(Long applyDepartId) {
		this.applyDepartId = applyDepartId;
	}

	public String getApplyDepartName() {
		return applyDepartName;
	}

	public void setApplyDepartName(String applyDepartName) {
		this.applyDepartName = applyDepartName;
	}

	public String getOutBillNo() {
		return outBillNo;
	}

	public void setOutBillNo(String outBillNo) {
		this.outBillNo = outBillNo;
	}

	public List<LogisticList> getLogisticList() {
		return logisticList;
	}

	public void setLogisticList(List<LogisticList> logisticList) {
		this.logisticList = logisticList;
	}

	public String getGmtModified() {
		return gmtModified;
	}

	public void setGmtModified(String gmtModified) {
		this.gmtModified = gmtModified;
	}

	public String getDepartCode() {
		return departCode;
	}

	public void setDepartCode(String departCode) {
		this.departCode = departCode;
	}

	public String getApplyCompanyName() {
		return applyCompanyName;
	}

	public void setApplyCompanyName(String applyCompanyName) {
		this.applyCompanyName = applyCompanyName;
	}

	public String getApplyCompanyCode() {
		return applyCompanyCode;
	}

	public void setApplyCompanyCode(String applyCompanyCode) {
		this.applyCompanyCode = applyCompanyCode;
	}

	public Long getApplyCompanyId() {
		return applyCompanyId;
	}

	public void setApplyCompanyId(Long applyCompanyId) {
		this.applyCompanyId = applyCompanyId;
	}

	public Long getApplyUserId() {
		return applyUserId;
	}

	public void setApplyUserId(Long applyUserId) {
		this.applyUserId = applyUserId;
	}

	public String getApplyUserName() {
		return applyUserName;
	}

	public void setApplyUserName(String applyUserName) {
		this.applyUserName = applyUserName;
	}

	public String getCompanyCode() {
		return companyCode;
	}

	public void setCompanyCode(String companyCode) {
		this.companyCode = companyCode;
	}

	public List<GoodsDocDetailList> getGoodsDocDetailList() {
		return goodsDocDetailList;
	}

	public void setGoodsDocDetailList(List<GoodsDocDetailList> goodsDocDetailList) {
		this.goodsDocDetailList = goodsDocDetailList;
	}

	public String getSendCompanyName() {
		return sendCompanyName;
	}

	public void setSendCompanyName(String sendCompanyName) {
		this.sendCompanyName = sendCompanyName;
	}

	public String getSend() {
		return send;
	}

	public void setSend(String send) {
		this.send = send;
	}

	public String getSendTel() {
		return sendTel;
	}

	public void setSendTel(String sendTel) {
		this.sendTel = sendTel;
	}

	public String getSendPhone() {
		return sendPhone;
	}

	public void setSendPhone(String sendPhone) {
		this.sendPhone = sendPhone;
	}

	public String getSendEmail() {
		return sendEmail;
	}

	public void setSendEmail(String sendEmail) {
		this.sendEmail = sendEmail;
	}

	public String getSendCountryName() {
		return sendCountryName;
	}

	public void setSendCountryName(String sendCountryName) {
		this.sendCountryName = sendCountryName;
	}

	public String getSendProvinceName() {
		return sendProvinceName;
	}

	public void setSendProvinceName(String sendProvinceName) {
		this.sendProvinceName = sendProvinceName;
	}

	public String getSendCityName() {
		return sendCityName;
	}

	public void setSendCityName(String sendCityName) {
		this.sendCityName = sendCityName;
	}

	public String getSendTownName() {
		return sendTownName;
	}

	public void setSendTownName(String sendTownName) {
		this.sendTownName = sendTownName;
	}

	public String getSendStreetName() {
		return sendStreetName;
	}

	public void setSendStreetName(String sendStreetName) {
		this.sendStreetName = sendStreetName;
	}

	public String getSendAddress() {
		return sendAddress;
	}

	public void setSendAddress(String sendAddress) {
		this.sendAddress = sendAddress;
	}

	public String getReceiveCompanyName() {
		return receiveCompanyName;
	}

	public void setReceiveCompanyName(String receiveCompanyName) {
		this.receiveCompanyName = receiveCompanyName;
	}

	public String getReceive() {
		return receive;
	}

	public void setReceive(String receive) {
		this.receive = receive;
	}

	public String getReceiveTel() {
		return receiveTel;
	}

	public void setReceiveTel(String receiveTel) {
		this.receiveTel = receiveTel;
	}

	public String getReceivePhone() {
		return receivePhone;
	}

	public void setReceivePhone(String receivePhone) {
		this.receivePhone = receivePhone;
	}

	public String getReceiveEmail() {
		return receiveEmail;
	}

	public void setReceiveEmail(String receiveEmail) {
		this.receiveEmail = receiveEmail;
	}

	public String getReceiveCountryName() {
		return receiveCountryName;
	}

	public void setReceiveCountryName(String receiveCountryName) {
		this.receiveCountryName = receiveCountryName;
	}

	public String getReceiveProvinceName() {
		return receiveProvinceName;
	}

	public void setReceiveProvinceName(String receiveProvinceName) {
		this.receiveProvinceName = receiveProvinceName;
	}

	public String getReceiveCityName() {
		return receiveCityName;
	}

	public void setReceiveCityName(String receiveCityName) {
		this.receiveCityName = receiveCityName;
	}

	public String getReceiveTownName() {
		return receiveTownName;
	}

	public void setReceiveTownName(String receiveTownName) {
		this.receiveTownName = receiveTownName;
	}

	public String getReceiveStreetName() {
		return receiveStreetName;
	}

	public void setReceiveStreetName(String receiveStreetName) {
		this.receiveStreetName = receiveStreetName;
	}

	public String getReceiveAddress() {
		return receiveAddress;
	}

	public void setReceiveAddress(String receiveAddress) {
		this.receiveAddress = receiveAddress;
	}

	public String getField6() {
		return field6;
	}

	public void setField6(String field6) {
		this.field6 = field6;
	}

	public String getField7() {
		return field7;
	}

	public void setField7(String field7) {
		this.field7 = field7;
	}

	public String getField8() {
		return field8;
	}

	public void setField8(String field8) {
		this.field8 = field8;
	}

	public String getField9() {
		return field9;
	}

	public void setField9(String field9) {
		this.field9 = field9;
	}

	public String getField10() {
		return field10;
	}

	public void setField10(String field10) {
		this.field10 = field10;
	}
}

==> zhiyuan-openapi-sdk-0.0.33-20251112.081333-1-sources.jar: com/elitesland/zhiyuan/openapi/outer/jackyun/data/bizdata/erp/erpstoragegoodsdocoutv2/ErpStorageGoodsDocOutV2ResponseBizData.java <==
package com.elitesland.zhiyuan.openapi.outer.jackyun.data.bizdata.erp.erpstoragegoodsdocoutv2;



import com.elitesland.zhiyuan.openapi.outer.jackyun.data.bizdata.core.BaseResponseBizData;
import lombok.Data;

import java.math.BigDecimal;
import java.util.List;
/**
 * @description: 分页查询出库单返回参数
 * @author: luoxin
 */
@Data
public class ErpStorageGoodsDocOutV2ResponseBizData extends BaseResponseBizData {
	/**
	 * 出库单ID 
	 */ 
	private Long recId;
	/**
	 * 出库单号 
	 */ 
	private String goodsdocNo;
	/**
	 * 上游单据号(关联单号) 
	 */ 
	private String billNo;
	/**
	 * 出库时间 
	 */ 
	private String inOutDate;
	/**
	 * 创建时间 
	 */ 
	private String gmtCreate;
	/**
	 * 出入库类型(201-销售出库 202调拨出库 204-其他出库 205采购退货 206生产领料 207组装拆卸出库 208翻新出库 209报废出库 210残次品出库 211倒冲领料 212 包材出库 215维修还厂 299可用库存修正 231成本调整出库) 
	 */ 
	private Integer inouttype;
	/**
	 * 出入库类型(201-销售出库 202调拨出库 204-其他出库 205采购退货 206生产领料 207组装拆卸出库 208翻新出库 209报废出库 210残次品出库 211倒冲领料 212 包材出库 215维修还厂 299可用库存修正 231成本调整出库) 
	 */ 
	private String inouttypeName;
	/**
	 * 往来单位名称 
	 */ 
	private String vendCustomerName;
	/**
	 * 币种编号 
	 */ 
	private String currencyCode;
	/**
	 * 币种汇率 
	 */ 
	private BigDecimal currencyRate;
	/**
	 * 业务员名字 
	 */ 
	private String userName;
	/**
	 * 仓库编号 
	 */ 
	private String warehouseCode;
	/**
	 * 仓库名字 
	 */ 
	private String warehouseName;
	/**
	 * 备注 
	 */ 
	private String comment;
	/**
	 * 收货备注 
	 */ 
	private String memo;
	/**
	 * 物流公司 
	 */ 
	private String logisticName;
	/**
	 * 物流单号 
	 */ 
	private String logisticNo;
	/**
	 * 公司id 
	 */ 
	private Long companyId;
	/**
	 * 公司名称 
	 */ 
	private String companyName;
	/**
	 * 物流类型1-普通快递 2-上门自提 3-门店配送5-无需配送 6-线下配送 
	 */ 
	private String logisticType;
	/**
	 * 物流公司编码 
	 */ 
	private String logisticCode;
	/**
	 * 出库原因 
	 */ 
	private String inOutReason;
	/**
	 * 来源单号 
	 */ 
	private String sourceBillNo;
	/**
	 * 渠道ID 
	 */ 
	private Long channelId;
	/**
	 * 渠道编号 
	 */ 
	private String channelCode;
	/**
	 * 渠道名称 
	 */ 
	private String channelName;
	/**
	 * 红冲状态：1蓝单（未红冲）；2被冲蓝单；9红冲单 
	 */ 
	private Byte redStatus;
	/**
	 * 自定义字段1 
	 */ 
	private String field1;
	/**
	 * 自定义字段2 
	 */ 
	private String field2;
	/**
	 * 自定义字段3 
	 */ 
	private String field3;
	/**
	 * 自定义字段4 
	 */ 
	private String field4;
	/**
	 * 自定义字段5 
	 */ 
	private String field5;
	/**
	 * 财务状态：1：未成本计算；11部分成本计算；21：已成本计算；25已财务记账；31不成本计算 
	 */ 
	private Byte financeBillStatus;
	/**
	 * 往来单位的id 
	 */ 
	private String vendCustomerId;
	/**
	 * 申请人部门id 
	 */ 
	private Long applyDepartId;
	/**
	 * 申请人部门名称 
	 */ 
	private String applyDepartName;
	/**
	 * 外部单号 
	 */ 
	private String outBillNo;
	/**
	 * 物流信息 
	 */ 
	private List<LogisticList> logisticList;
	/**
	 * 最近修改时间 
	 */ 
	private String gmtModified;
	/**
	 * 申请人部门编号 
	 */ 
	private String departCode;
	/**
	 * 申请人公司名称 
	 */ 
	private String applyCompanyName;
	/**
	 * 申请人公司编号 
	 */ 
	private String applyCompanyCode;
	/**
	 * 申请人公司id 
	 */ 
	private Long applyCompanyId;
	/**
	 * 申请人id 
	 */ 
	private Long applyUserId;
	/**
	 * 申请人名称 
	 */ 
	private String applyUserName;
	/**
	 * 公司编号 
	 */ 
	private String companyCode;
	/**
	 * 出库单详情 
	 */ 
	private List<GoodsDocDetailList> goodsDocDetailList;
	/**
	 * 发件公司名称 
	 */ 
	private String sendCompanyName;
	/**
	 * 发件人 
	 */ 
	private String send;
	/**
	 * 发件人电话 
	 */ 
	private String sendTel;
	/**
	 * 发件人手机号 
	 */ 
	private String sendPhone;
	/**
	 * 发件人邮箱 
	 */ 
	private String sendEmail;
	/**
	 * 发件人国家 
	 */ 
	private String sendCountryName;
	/**
	 * 发件人省 
	 */ 
	private String sendProvinceName;
	/**
	 * 发件人市 
	 */ 
	private String sendCityName;
	/**
	 * 发件人镇，区 
	 */ 
	private String sendTownName;
	/**
	 * 发件人街道 
	 */ 
	private String sendStreetName;
	/**
	 * 发件人详细地址 
	 */ 
	private String sendAddress;
	/**
	 * 收件公司名称 
	 */ 
	private String receiveCompanyName;
	/**
	 * 收件人 
	 */ 
	private String receive;
	/**
	 * 收件人电话 
	 */ 
	private String receiveTel;
	/**
	 * 收件人手机号 
	 */ 
	private String receivePhone;
	/**
	 * 收件人邮箱 
	 */ 
	private String receiveEmail;
	/**
	 * 收件人国家 
	 */ 
	private String receiveCountryName;
	/**
	 * 收件人省 
	 */ 
	private String receiveProvinceName;
	/**
	 * 收件人市 
	 */ 
	private String receiveCityName;
	/**
	 * 收件人镇，区 
	 */ 
	private String receiveTownName;
	/**
	 * 收件人街道 
	 */ 
	private String receiveStreetName;
	/**
	 * 收件人详细地址 
	 */ 
	private String receiveAddress;
	/**
	 * 自定义字段6 
	 */ 
	private String field6;
	/**
	 * 自定义字段7 
	 */ 
	private String field7;
	/**
	 * 自定义字段8 
	 */ 
	private String field8;
	/**
	 * 自定义字段9 
	 */ 
	private String field9;
	/**
	 * 自定义字段10 
	 */ 
	private String field10;


}
